==> beast-0.4.1.tar.gz: beast-0.4.1/bse/bsehelloworld.gen-proc.c <==

/**
 ** Generated data (by mkcproc.pl)
 **/
#line 1 "bsehelloworld.proc"

#include        <bse/bseplugin.h>
#include        <bse/bseprocedure.h>

#include	<stdlib.h>


#line 28 "bsehelloworld.proc"


/* --- bse-hello-world --- */
static GType type_id_bse_hello_world = 0;
static void
bse_hello_world_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
#line 30 "bsehelloworld.proc"
 {
#line 35 "bsehelloworld.proc"
  
#line 31 "bsehelloworld.proc"
  proc->help = ("Hello World - First Plugin ever executed by BSE. "
	   "Its purpose is to say \"Hello World\" to BSE and the "
	   "general outside. This plugin takes no input or output"
	   "parameters.");
#line 25 "bsehelloworld.proc"
  proc->author = "Tim Janik <timj@gtk.org>";
#line 26 "bsehelloworld.proc"
  proc->copyright = "Tim Janik";
#line 27 "bsehelloworld.proc"
  proc->date = "1999";
#line 36 "bsehelloworld.proc"
}  }
static BseErrorType
#line 36 "bsehelloworld.proc"
bse_hello_world_exec (BseProcedureClass *proc,
	const GValue      *in_values,
	GValue            *out_values)
#line 39 "bsehelloworld.proc"
{
#line 40 "bsehelloworld.proc"
  
  g_message ("Hello World");

  return BSE_ERROR_NONE;
}

/* --- bse-randomizer --- */
static GType type_id_bse_randomizer = 0;
static void
bse_randomizer_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
#line 46 "bsehelloworld.proc"
 {
#line 51 "bsehelloworld.proc"
  
#line 52 "bsehelloworld.proc"
  
  *(in_pspecs++) = bse_param_spec_bool ("use-seed", "Use seed value?", NULL,
			     FALSE, BSE_PARAM_DEFAULT);
  *(in_pspecs++) = bse_param_spec_int ("seed", "Random Seed", NULL,
			    -32768, 32767, 42, 1, BSE_PARAM_DEFAULT);
#line 57 "bsehelloworld.proc"
  
  *(out_pspecs++) = bse_param_spec_string ("text", "Random Text", NULL,
			       NULL, BSE_PARAM_DEFAULT);
#line 47 "bsehelloworld.proc"
  proc->help = ("Randomizer will take on integer as input parameter, "
	   "use it as seed value and return a string containing "
	   "a random number. The deeper sense behind this plugin "
	   "is to test out the parameter passing functionality.");
#line 25 "bsehelloworld.proc"
  proc->author = "Tim Janik <timj@gtk.org>";
#line 26 "bsehelloworld.proc"
  proc->copyright = "Tim Janik";
#line 27 "bsehelloworld.proc"
  proc->date = "1999";
#line 60 "bsehelloworld.proc"
}  }
static BseErrorType
#line 60 "bsehelloworld.proc"
bse_randomizer_exec (BseProcedureClass *proc,
	const GValue      *in_values,
	GValue            *out_values)
#line 63 "bsehelloworld.proc"
{
#line 64 "bsehelloworld.proc"
  
  gint use_seed = g_value_get_boolean (in_values++);
  gint seed     = g_value_get_int (in_values++);
  gchar *string;

#line 69 "bsehelloworld.proc"
  
  if (use_seed && seed == 0)
    return BSE_ERROR_PROC_PARAM_INVAL;

#line 73 "bsehelloworld.proc"
  
  if (use_seed)
    srand (seed);

  string = g_strdup_printf ("Random Number: %d", rand ());

#line 79 "bsehelloworld.proc"
  
  g_value_set_string (out_values++, string);
  g_free (string);

  return BSE_ERROR_NONE;
}

/* --- Export to BSE --- */
BSE_EXPORTS_BEGIN (BSE_PLUGIN_NAME);
BSE_EXPORT_PROCEDURES = {
  { &type_id_bse_hello_world, "bse-hello-world", NULL, 0, bse_hello_world_setup, bse_hello_world_exec, NULL, "/Proc/Toys/Hello World", { 0, }, },
  { &type_id_bse_randomizer, "bse-randomizer", NULL, 0, bse_randomizer_setup, bse_randomizer_exec, NULL, "/Proc/Toys/Randomizer", { 0, }, },
  { NULL, },
};
BSE_EXPORTS_END;

/**
 ** Generated data ends here
 **/

==> beast-0.5.2-rc2.tar.gz: beast-0.5.2-rc2/bse/bsehelloworld.gen-proc.c <==

/**
 ** Generated data (by mkcproc.pl)
 **/
#line 1 "bsehelloworld.proc"

#include        <bse/bseplugin.h>
#include        <bse/bseprocedure.h>

#include	<stdlib.h>


#line 27 "bsehelloworld.proc"


/* --- bse-hello-world --- */
static GType type_id_bse_hello_world = 0;
static void
bse_hello_world_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
#line 29 "bsehelloworld.proc"
 {
#line 34 "bsehelloworld.proc"
  
#line 30 "bsehelloworld.proc"
  proc->help = ("Hello World - First Plugin ever executed by BSE. "
	   "Its purpose is to say \"Hello World\" to BSE and the "
	   "general outside. This plugin takes no input or output"
	   "parameters.");
#line 25 "bsehelloworld.proc"
  proc->authors = "Tim Janik <timj@gtk.org>";
#line 26 "bsehelloworld.proc"
  proc->copyright = "Copyright (C) 1999 Tim Janik";
#line 35 "bsehelloworld.proc"
}  }
static BseErrorType
#line 35 "bsehelloworld.proc"
bse_hello_world_exec (BseProcedureClass *proc,
	const GValue      *in_values,
	GValue            *out_values)
#line 38 "bsehelloworld.proc"
{
#line 39 "bsehelloworld.proc"
  
  g_message ("Hello World");
  
  return BSE_ERROR_NONE;
}

/* --- bse-randomizer --- */
static GType type_id_bse_randomizer = 0;
static void
bse_randomizer_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
#line 45 "bsehelloworld.proc"
 {
#line 50 "bsehelloworld.proc"
  
#line 51 "bsehelloworld.proc"
  
  *(in_pspecs++) = sfi_pspec_bool ("use-seed", "Use seed value?", NULL,
			  FALSE, SFI_PARAM_DEFAULT);
  *(in_pspecs++) = sfi_pspec_int ("seed", "Random Seed", NULL,
			 42, -32768, 32767, 1, SFI_PARAM_DEFAULT);
#line 56 "bsehelloworld.proc"
  
  *(out_pspecs++) = sfi_pspec_string ("text", "Random Text", NULL,
			    NULL, SFI_PARAM_DEFAULT);
#line 46 "bsehelloworld.proc"
  proc->help = ("Randomizer will take on integer as input parameter, "
	   "use it as seed value and return a string containing "
	   "a random number. The deeper sense behind this plugin "
	   "is to test out the parameter passing functionality.");
#line 25 "bsehelloworld.proc"
  proc->authors = "Tim Janik <timj@gtk.org>";
#line 26 "bsehelloworld.proc"
  proc->copyright = "Copyright (C) 1999 Tim Janik";
#line 59 "bsehelloworld.proc"
}  }
static BseErrorType
#line 59 "bsehelloworld.proc"
bse_randomizer_exec (BseProcedureClass *proc,
	const GValue      *in_values,
	GValue            *out_values)
#line 62 "bsehelloworld.proc"
{
#line 63 "bsehelloworld.proc"
  
  gint use_seed = g_value_get_boolean (in_values++);
  gint seed     = g_value_get_int (in_values++);
  gchar *string;
  
#line 68 "bsehelloworld.proc"
  
  if (use_seed && seed == 0)
    return BSE_ERROR_PROC_PARAM_INVAL;
  
#line 72 "bsehelloworld.proc"
  
  if (use_seed)
    srand (seed);
  
  string = g_strdup_printf ("Random Number: %d", rand ());
  
#line 78 "bsehelloworld.proc"
  
  g_value_set_string (out_values++, string);
  g_free (string);
  
  return BSE_ERROR_NONE;
}

/* --- Export to BSE --- */
BSE_EXPORTS_BEGIN (BSE_PLUGIN_NAME);
BSE_EXPORT_PROCEDURES = {
  { &type_id_bse_hello_world, "bse-hello-world", NULL, 0, bse_hello_world_setup, bse_hello_world_exec, NULL, "/Proc/Toys/Hello World", { 0, }, },
  { &type_id_bse_randomizer, "bse-randomizer", NULL, 0, bse_randomizer_setup, bse_randomizer_exec, NULL, "/Proc/Toys/Randomizer", { 0, }, },
  { NULL, },
};
BSE_EXPORTS_END;

/**
 ** Generated data ends here
 **/
